Trait ntex_codec::Decoder [−][src]
pub trait Decoder {
type Item;
type Error: Debug;
fn decode(
&self,
src: &mut BytesMut
) -> Result<Option<Self::Item>, Self::Error>;
fn decode_eof(
&self,
buf: &mut BytesMut
) -> Result<Option<Self::Item>, Self::Error> { ... }
}Expand description
Decoding of frames via buffers.
Associated Types
Required methods
Provided methods
A default method available to be called when there are no more bytes available to be read from the underlying I/O.
This method defaults to calling decode and returns an error if
Ok(None) is returned while there is unconsumed data in buf.
Typically this doesn’t need to be implemented unless the framing
protocol differs near the end of the stream.